abacusai.project_config — AbacusAI documentation

# abacusai.project_config

## Classes

`ProjectFeatureGroupConfig` | An abstract class for project feature group configuration.
`AbstractApiClass` |
`ProjectConfig` | Project-specific config for a feature group

## Module Contents

class abacusai.project_config.ProjectFeatureGroupConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  An abstract class for project feature group configuration.

  type: abacusai.api_class.enums.ProjectConfigType
  classmethod _get_builder()

class abacusai.project_config.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.project_config.ProjectConfig(client, type=None, config={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Project-specific config for a feature group

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - type (str) – Type of project config

    - config (ProjectFeatureGroupConfig) – Project-specific config for this feature group

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict